@@ -1,6 +1,5 @@
 from abc import ABC, abstractmethod
 from time import time
-from lto.public_node import PublicNode
 import base58
 from nacl.signing import VerifyKey
 
@@ -44,10 +43,11 @@ class Transaction(ABC):
             raise Exception('Transaction must be signed first')
 
         self.sponsor = sponsor_account.address
-        self.sponsor_public_key = sponsor_account.public_key
+        self.sponsor_public_key = base58.b58encode(sponsor_account.public_key.__bytes__())
+        self.sponsor_key_type = sponsor_account.key_type
         self.proofs.append(sponsor_account.sign(self.to_binary()))
 
-    def broadcast_to(self, node: PublicNode):
+    def broadcast_to(self, node):
         return node.broadcast(self)
 
     @abstractmethod
@@ -57,7 +57,7 @@ class Transaction(ABC):
     def _sponsor_json(self):
         if self.sponsor:
             return {"sponsor": self.sponsor,
-                    "sponsorPublicKey": base58.b58encode(self.sponsor_public_key.__bytes__()),
+                    "sponsorPublicKey": self.sponsor_public_key,
                     "sponsorKeyType": self.sponsor_key_type}
         else:
             return{}
